@@ -4,6 +4,7 @@
 # imports.
 from r3sponse.v1.classes.config import *
 from r3sponse.v1.classes import utils
+from r3sponse.v1.classes.utils import color, symbol
 from django.http import JsonResponse
 
 # the manager class.
@@ -117,11 +118,13 @@ class R3sponse(object):
 		if [message,response] == [None,{}]:
 			raise ValueError("Define either parameter [message:str] or [response:dict].")
 		if response != {}:
-			if response["error"] != None: msg = f"Error: {response['error']}"
-			else: msg = response['message']
-		else: msg = message
-		print(msg)
-		print(utils.color.fill(msg))
+			if response["error"] != None: 
+				msg = f"Error: {response['error']}"
+			else: 
+				msg = response["message"]
+		else: 
+			msg = message
+		print(color.fill(msg))
 		if save: self.__log_to_file__(msg)
 
 		#
